# Remote Image Styles

The **Remote Image Styles** module enables Drupal core to generate image styles for remotely hosted images in the image field.

## INTRODUCTION

Drupal core allows storing records about remote URLs (e.g., `https://...`) alongside records about uploaded files in file entities.
However, it cannot generate image derivatives (styles) for remote images.
This small module addresses that limitation by hooking into the style generation process, downloading a remote image, and temporarily storing it in the site's local filesystem, so derivatives can be generated as usual.

**Note:** Currently, there is no field widget to set the URL of a remote image in the UI ([you can help implement it](https://www.drupal.org/i/3491022)).
However, it is possible to do this programmatically (e.g., during imports, migrations, etc.) by creating a file entity with a remote URI (`https://...`) and assigning it to the entity's image field.

**Note:** Currently, the module does not work with the responsive image formatter ([you can help implement it](https://www.drupal.org/i/3491019)).

**Important:** Plain `http` is not supported due to potential security risks.
Only `https` is supported.

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/ris).

## INSTALLATION

Install the module as you would install any contributed Drupal module.
For more information, see the [Drupal module installation guide](https://www.drupal.org/docs/extending-drupal/installing-modules).

## CONFIGURATION

No configuration is required.

## SIMILAR MODULES

The following modules (listed alphabetically) also allow generating image styles for remote images.
Since they function differently from this module, they come with their own unique features.
Please review their documentation to determine the best fit for your project.

- [Imagecache External](https://www.drupal.org/project/imagecache_external)

  > A utility module that allows you to store external images on your server and apply your own Image Styles.

  Currently, this module does not work with the default image field type and formatter.


- [Remote Stream Wrapper](https://www.drupal.org/project/remote_stream_wrapper)

  > Provides the ability to use external files with file fields without saving the files to your local files directory.

  This module registers a stream wrapper for remote protocols (`http`/`https`).
  This means that any file or stream function called with a remote URI argument goes through it instead of using native PHP or platform libraries.
  For the sole purpose of generating image styles, this approach might be overkill.

## MAINTAINERS

[//]: # (cspell:disable-next-line)
- [Mykhailo Shyian (pingwin4eg)](https://www.drupal.org/u/pingwin4eg)
