<?php

namespace Drupal\ris;

use Drupal\Core\Image\Image;
use Drupal\Core\Image\ImageFactory;
use Drupal\Core\ImageToolkit\ImageToolkitManager;

/**
 * Decorates a factory for image objects.
 */
class RisImageFactory extends ImageFactory {

  /**
   * Constructs a new RisImageFactory object.
   */
  public function __construct(
    protected ImageFactory $decorated,
    protected RisService $risService,
    ImageToolkitManager $toolkit_manager,
  ) {
    parent::__construct($toolkit_manager);
  }

  /**
   * {@inheritdoc}
   */
  public function setToolkitId($toolkit_id): static {
    $this->decorated->setToolkitId($toolkit_id);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getToolkitId() {
    return $this->decorated->getToolkitId();
  }

  /**
   * {@inheritdoc}
   */
  public function get($source = NULL, $toolkit_id = NULL): Image {
    if ($source && $file = $this->risService->getRemoteFile($source)) {
      $toolkit_id = $toolkit_id ?: $this->getToolkitId();
      $image = $this->doGet($source, $toolkit_id);

      if (!$image->isValid()) {
        // Try to download the image.
        $image = $this->doGet($this->risService->download($file), $toolkit_id);
      }

      return $image;
    }

    return $this->decorated->get($source, $toolkit_id);
  }

  /**
   * Constructs a new RemoteImage object.
   */
  protected function doGet(string $source, string $toolkit_id): RemoteImage {
    /** @var \Drupal\Core\ImageToolkit\ImageToolkitInterface $toolkit */
    $toolkit = $this->toolkitManager->createInstance($toolkit_id);
    return new RemoteImage($toolkit, $source);
  }

  /**
   * {@inheritdoc}
   */
  public function getSupportedExtensions($toolkit_id = NULL) {
    return $this->decorated->getSupportedExtensions($toolkit_id);
  }

}
