<?php

declare(strict_types=1);

namespace Drupal\Tests\ris\Functional;

use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\ris\Traits\CommonThingsTrait;

/**
 * Tests ris module event subscription.
 *
 * @group ris
 */
class EventTest extends BrowserTestBase {

  use CommonThingsTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'ris',
    'file',
    'image',
    'system',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests the 'kernel.controller' event subscription.
   */
  public function testOnControllerDownload(): void {
    File::create([
      'fid' => $fid = rand(),
      'uri' => $this->remoteImageUrl,
      'filename' => $filename = $this->randomMachineName() . '.' . $this->remoteImageExtension,
    ])->save();
    $image_style = ImageStyle::load('thumbnail');

    // @see \Drupal\Tests\image\Functional\ImageStylesPathAndUrlTest::doImageStyleUrlAndPathTests()
    $this->prepareRequestForGenerator(TRUE);
    $this->config('system.file')->set('default_scheme', 'temporary')->save();

    // The result of RisService->buildLocalUri() .
    $local_uri = "public://ris/$fid-$filename";
    // The result of $image_style->buildUri($local_uri) .
    $img_drv_uri = "public://styles/thumbnail/public/ris/$fid-$filename.webp";

    $this->assertFileDoesNotExist($local_uri);
    $this->assertFileDoesNotExist($img_drv_uri);

    // Fetch the URL that generates the file.
    $generate_url = $image_style->buildUrl($local_uri, TRUE);
    $this->drupalGet($generate_url);

    $this->assertFileExists($local_uri);
    $this->assertSame(file_get_contents($this->remoteImageUrl), file_get_contents($local_uri));

    $this->assertFileExists($img_drv_uri);
    $this->assertNotEmpty(file_get_contents($img_drv_uri));

    $this->assertSession()->statusCodeEquals(200);
  }

}
