<?php

declare(strict_types=1);

namespace Drupal\Tests\ris\Kernel;

use Drupal\Core\File\FileSystemInterface;
use Drupal\image\Entity\ImageStyle;
use Drupal\KernelTests\KernelTestBase;

/**
 * Tests ris module installation and uninstallation.
 *
 * @group ris
 */
class InstallTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    // Image module is required for ris_uninstall().
    'file',
    'image',
    'system',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installSchema('user', ['users_data']);

    ImageStyle::create(['name' => 'main_style', 'label' => 'Main'])->save();
  }

  /**
   * Tests installation and uninstallation tasks.
   */
  public function testInstallUninstall(): void {
    // Install the module and check that the directory for temporary files is
    // created.
    $this->assertTrue(\Drupal::service('module_installer')->install(['ris']));
    $this->assertDirectoryIsWritable('public://ris');

    $styles = ImageStyle::loadMultiple();
    $style = reset($styles)->id();
    $style_dir = "public://styles/$style/public/ris";

    // Put random files.
    file_put_contents('public://ris/test', 'test');
    \Drupal::service('file_system')->prepareDirectory(
      $style_dir,
      FileSystemInterface::CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS,
    );
    file_put_contents("$style_dir/test", 'test');

    // Uninstall and check that directories are deleted.
    $this->assertTrue(\Drupal::service('module_installer')->uninstall(['ris']));
    $this->assertDirectoryDoesNotExist('public://ris');
    $this->assertDirectoryDoesNotExist($style_dir);
  }

}
