<?php

declare(strict_types=1);

namespace Drupal\Tests\ris\Kernel;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\file\Entity\File;
use Drupal\Tests\field\Kernel\FieldKernelTestBase;
use Drupal\Tests\ris\Traits\CommonThingsTrait;

/**
 * Tests the RemoteImage class.
 *
 * @group ris
 */
class RemoteImageTest extends FieldKernelTestBase {

  use CommonThingsTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'ris',
    'file',
    'image',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('file');
    $this->installSchema('file', 'file_usage');

    FieldStorageConfig::create([
      'entity_type' => 'entity_test',
      'field_name' => 'image_test',
      'type' => 'image',
      'cardinality' => FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED,
    ])->save();
    FieldConfig::create([
      'entity_type' => 'entity_test',
      'field_name' => 'image_test',
      'bundle' => 'entity_test',
      'settings' => [
        'file_extensions' => $this->remoteImageExtension,
        'alt_field_required' => FALSE,
      ],
    ])->save();
  }

  /**
   * Tests saving a remote image in the image field without warnings.
   */
  public function testSavingImageField(): void {
    $image_file = File::create([
      'fid' => $fid = rand(),
      'uri' => $this->remoteImageUrl,
    ]);
    $entity = EntityTest::create();
    $entity->image_test = $image_file;
    $entity->save();

    $entity = EntityTest::load($entity->id());
    $this->assertEquals($fid, $entity->image_test->target_id);
    $this->assertGreaterThan(0, $entity->image_test->width);
    $this->assertGreaterThan(0, $entity->image_test->height);

    /** @var \Drupal\file\FileInterface $image_file */
    $image_file = $entity->image_test->entity;
    $this->assertSame($this->remoteImageUrl, $image_file->getFileUri());
    $this->assertSame(basename($this->remoteImageUrl), $image_file->getFilename());
    $this->assertSame('image/' . $this->remoteImageExtension, $image_file->getMimeType());
    $this->assertTrue($image_file->isPermanent());
  }

}
